@@ -83,7 +83,7 @@ class DenMune():
                   train_truth=None, test_truth=None, 
                   file_2d ='_temp_2d', k_nearest=1, 
                   rgn_tsne=False, prop_step=0,
-                  verpose=True
+                  show_analyzer=True
                   ):     
          
         if train_data is None:
@@ -179,7 +179,7 @@ class DenMune():
         
         self.alg_name = 'denmune'
         self.prop_step = prop_step
-        self.verpose = verpose
+        self.show_analyzer = show_analyzer
         self.data = data
         self.train_data = train_data
         self.test_data = test_data
@@ -555,18 +555,18 @@ class DenMune():
             self.plot_clusters(show_plots=show_plots, show_noise=show_noise, data_type='ground')
 
         if validate and self.data_indicator >= 1: 
-
+      
            if self.data_indicator >= 3:
                validity_scores = self.validate_Clusters(data_type='train') 
          
            print ('Plotting train data')  
            self.plot_clusters(show_plots=show_plots, show_noise=show_noise, data_type='train')
-           if self.verpose:
+           if self.show_analyzer:
                self.show_Analyzer(root='Validating train data')   
 
            if self.data_indicator == 15:
                validity_scores = self.validate_Clusters(data_type='test') 
-               if self.verpose:
+               if self.show_analyzer:
                    self.show_Analyzer(self.analyzer['validity']['test'], root='Validating test data')
           
            if self.data_indicator > 3:
@@ -575,7 +575,7 @@ class DenMune():
           
            if self.data_indicator == 15:
                validity_scores = self.validate_Clusters(data_type='augmented') 
-               if self.verpose:
+               if self.show_analyzer:
                    self.show_Analyzer(self.analyzer['validity']['augmented'], root='Validating augmented data (train & test)')
 
            if self.data_indicator > 3: 
@@ -824,7 +824,7 @@ class DenMune():
               elif data_type == 'augmented':
                 plt.scatter(self.data.T[0], self.data.T[1], c=colors, **plot_kwds, marker='o')
               elif data_type == 'ground':
-                plt.scatter(self.data.T[0], self.data.T[1], c=colors, **plot_kwds, marker='o')  
+                 plt.scatter(self.data[:self.train_sz].T[0], self.data[:self.train_sz].T[1], c=colors, **plot_kwds, marker='o')
         
           self.colors = colors
           frame = plt.gca()
